# 量化术语

择时策略
夏普率

最大回撤 MaxDD
回撤率是指基金在一段时间内,其净值从最高的位置,下跌到最低位置的幅度,即回撤率=(历史高点-历史低点)/历史高点×100%。

市场投资者
市场投机者
趋势跟踪
年化收益率 AnnRet
Annvol 年化波动率
Calmar 卡玛比率




成长就是找到一家能在未来几年利润数倍增长的企业，如去年的宁德时代和隆基股份，利润的增长叠加市场认可度的提升（市盈率的提升）实现了估值的乘数增长，也就是我们所说的戴维斯双击。

（1）低估和成长就是“支点投资法”中的那个支点，股票上涨我们要考虑股票本身的逻辑是否兑现，股票下跌要考虑支点是否消失
（2）拓宽自己的能力边界，能找到更多低估的股票，风险承受能力决定我们是否能忍受短期的波动，坚持长期的持股
（3）通过合理的资产配置降低自己持股的风险，大部分的仓位在稳健增长的品类中，用小部分的资金去追逐风险较高的成长股，即守正出奇


## A股抄底
一个是整个行业指数市盈率20%以下，开始定投分12份买入，这样可以很好的买在一个底部区间。【网格投资法】
一个是买指数不碰个股。行业指数分析要比个股简单的多。黑天鹅也少。
一个是一个月不创新低或者有地量再开始买。
